@@ -1,16 +1,12 @@
 package Lingua::SV::Numbers;
 
-use Exporter 5.57 'import';
-@EXPORT_OK = qw/num2sv num2sv_cardinal num2sv_ordinal/;
+use Exporter 'import';
+@EXPORT_OK = qw/num2sv num2sv_cardinal/;
 
 use warnings;
 use strict;
 use Carp;
 
-use constant {
-	ORDINAL => 1,	# flag passed to _translate()
-};
-
 
 
 #--------------
@@ -20,18 +16,11 @@ use constant {
 #   triljon: en miljon biljoner
 #   kvadriljon: en miljon triljoner
 my %bases;
-@bases{0..20,30,40,50,60,70,80,90,100,1_000,10**6,10**9,10**12,10**18} = qw/
+@bases{0..20,30,40,50,60,70,80,90,100,1_000,10**6,10**9,10**12,10**18,10**24} = qw/
 	noll ett två tre fyra fem sex sju åtta nio tio
 	elva tolv tretton fjorton femton sexton sjutton arton nitton
 	tjugo trettio fyrtio femtio sextio sjuttio åttio nittio
-	hundra tusen miljon miljard biljon triljon
-/;
-my %ordinalBases;
-@ordinalBases{sort {$a<=>$b} keys %bases} = qw/
-	nollte första andra tredje fjärde femte sjätte sjunde åttonde nionde tionde
-	elfte tolfte trettonde fjortonde femtonde sextonde sjuttonde artonde nittonde
-	tjugonde trettionde fyrtionde femtionde sextionde sjuttionde åttionde nittionde
-	hundrade tusende miljonte miljardte biljonte triljonte
+	hundra tusen miljon miljard biljon triljon kvadriljon
 /;
 
 
@@ -39,30 +28,23 @@ my %ordinalBases;
 #--------------
 
 
-*num2sv = \&num2sv_cardinal;
-sub num2sv_cardinal {
-	_num2sv( 0, @_ );
-}
-sub num2sv_ordinal {
-	_num2sv( ORDINAL, @_ );
-}
-sub _num2sv {
-	my $flags = shift;
+sub num2sv {
 	carp "not exactly one argument given" if ( @_ != 1 );
 	my $x = shift;
 	if ( $x =~ m/^-?\d+$/ ) {
-		return _translate( $flags, _reduce( $x ) );
+		return _translate( _reduce( $x ) );
 	} else {
 		carp "not an integer";
 		return $x;
 	}
 }
+*num2sv_cardinal = \&num2sv;
 
 #--------------
 
 # Translates an array of reduced components.
 sub _translate {
-	my $flags = shift;
+	#print "@_\n";
 	my $str = '';
 	if ( $_[0] eq '-' ) {
 		$str = 'minus ';
@@ -72,30 +54,20 @@ sub _translate {
 	while ( @_ ) {
 		my $cur = shift;
 		my $next = $_[0];
-
 		if ( $prev && $prev > $cur && _precedingOne( $cur ) ) {
-			$str .= ( _tWord( $cur ) ? 'ett' : 'en' );
-		}
-
-		if ( ! $next && $flags & ORDINAL ) {
-			if ( $cur > 10**6 ) {
-				carp( "There is no word for ordinal $cur in Swedish" );
-			}
-			$str .= $ordinalBases{$cur};
+			$str .= ( _tWord( $cur ) ? 'ett' : 'en' ) . $bases{$cur};
 		} elsif ( $cur == 1 && $next ) {
 			if ( _precedingOne( $next ) ) {
 				$str .= _tWord( $next ) ? 'ett' : 'en';
-			}
-		} elsif (
-			$prev && 1 < $prev && $prev < $cur &&
-			! _degeneratePlural( $cur )
-		) {
+			} else {}
+		} elsif ( $prev && $prev > 1 && ! _degeneratePlural( $cur ) ) {
 			$str .= $bases{$cur} . 'er';
 		} else {
 			$str .= $bases{$cur};
 		}
 		$prev = $cur;
 	}
+	#$str =~ s/^(hundra|tusen)/ett$1/;
 	$str =~ s/(.)\1{2,}/$1$1/g;
 	return $str;
 }
@@ -144,18 +116,19 @@ Lingua::SV::Numbers - Convert numbers into Swedish words.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.01
 
 =cut
 
-our $VERSION = '0.04.00';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
 
-    use Lingua::SV::Numbers qw/num2sv num2sv_ordinal/;
-    print num2sv( 99 ) . " luftballonger\n"; #-> nittionio luftballonger
-    print num2sv_ordinal( 13 ) . " timmen\n"; #-> trettonde timmen
+    use Lingua::SV::Numbers qw/num2sv/;
+    print num2sv( 99 ) . " röda luftballonger\n"; #-> nittionio röda luftballonger
+    print num2sv( 65536 ) . " bitar\n"; #-> sextiofemtusenfemhundratrettiosex bitar
+    print num2sv( 1001 ) . " natt\n"; #-> ettusenett
 
 =head1 FUNCTIONS
 
@@ -165,17 +138,12 @@ These functions are provided but not exported by default.
 
 =item num2sv EXPR
 
-Alias for C<num2sv_cardinal>.
+Returns the Swedish text corresponding to EXPR. Only integers (positive and
+negative) are supported.
 
 =item num2sv_cardinal EXPR
 
-Returns a Swedish string of the cardinal number corresponding to EXPR. Only
-integers (positive and negative) are supported. E.g. 3 => "tre"
-
-=item num2sv_ordinal EXPR
-
-Returns a Swedish string of the ordinal number corresponding to EXPR. Only
-integers (positive and negative) are supported. E.g. 3 => "tredje"
+Alias for C<num2sv>.
 
 =back
 
@@ -183,6 +151,8 @@ integers (positive and negative) are supported. E.g. 3 => "tredje"
 
 =over 4
 
+=item * num2sv_ordinal
+
 =item * support fractions
 
 =item * support scientific notation
